aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/core/SkEmptyShader.h
diff options
context:
space:
mode:
authorGravatar halcanary <halcanary@google.com>2015-08-27 07:41:13 -0700
committerGravatar Commit bot <commit-bot@chromium.org>2015-08-27 07:41:16 -0700
commit96fcdcc219d2a0d3579719b84b28bede76efba64 (patch)
tree0ec5ea0193d8292df8bf5ed9dd8498a5eb5763dd /src/core/SkEmptyShader.h
parent435af2f736c85c3274a0c6760a3523810750d237 (diff)
Style Change: NULL->nullptr
Diffstat (limited to 'src/core/SkEmptyShader.h')
-rw-r--r--src/core/SkEmptyShader.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/core/SkEmptyShader.h b/src/core/SkEmptyShader.h
index 7b87c284f7..6453e0e440 100644
--- a/src/core/SkEmptyShader.h
+++ b/src/core/SkEmptyShader.h
@@ -14,14 +14,14 @@
/**
* \class SkEmptyShader
* A Shader that always draws nothing. Its createContext always returns NULL.
*/
class SK_API SkEmptyShader : public SkShader {
public:
SkEmptyShader() {}
size_t contextSize() const override {
// Even though createContext returns NULL we have to return a value of at least
// sizeof(SkShader::Context) to satisfy SkSmallAllocator.
return sizeof(SkShader::Context);
}
@@ -31,7 +31,7 @@ public:
protected:
SkShader::Context* onCreateContext(const ContextRec&, void*) const override {
- return NULL;
+ return nullptr;
}
void flatten(SkWriteBuffer& buffer) const override {
@@ -14,14 +14,14 @@
/**
* \class SkEmptyShader
- * A Shader that always draws nothing. Its createContext always returns NULL.
+ * A Shader that always draws nothing. Its createContext always returns nullptr.
*/
class SK_API SkEmptyShader : public SkShader {
@@ -14,14 +14,14 @@
SkEmptyShader() {}
size_t contextSize() const override {
- // Even though createContext returns NULL we have to return a value of at least
+ // Even though createContext returns nullptr we have to return a value of at least
// sizeof(SkShader::Context) to satisfy SkSmallAllocator.
return sizeof(SkShader::Context);